pub struct ClaimRewards<'info> {
pub user: Signer<'info>,
pub staking_pool: Account<'info, StakingPool>,
pub stake_account: Account<'info, StakeAccount>,
pub user_reward_account: AccountInfo<'info>,
pub reward_token_account: AccountInfo<'info>,
pub token_program: Program<'info, Token>,
}Fields
user: Signer<'info>staking_pool: Account<'info, StakingPool>stake_account: Account<'info, StakeAccount>user_reward_account: AccountInfo<'info>CHECK: User’s reward token account
reward_token_account: AccountInfo<'info>CHECK: Pool’s reward token account
token_program: Program<'info, Token>Trait Implementations
Sourceimpl<'info> Accounts<'info, ClaimRewardsBumps> for ClaimRewards<'info>where
'info: 'info,
impl<'info> Accounts<'info, ClaimRewardsBumps> for ClaimRewards<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut ClaimRewardsBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut ClaimRewardsBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreSourceimpl<'info> AccountsExit<'info> for ClaimRewards<'info>where
'info: 'info,
impl<'info> AccountsExit<'info> for ClaimRewards<'info>where
'info: 'info,
Sourceimpl<'info> Bumps for ClaimRewards<'info>where
'info: 'info,
impl<'info> Bumps for ClaimRewards<'info>where
'info: 'info,
Sourcetype Bumps = ClaimRewardsBumps
type Bumps = ClaimRewardsBumps
Struct to hold account bump seeds.
Sourceimpl<'info> ToAccountInfos<'info> for ClaimRewards<'info>where
'info: 'info,
impl<'info> ToAccountInfos<'info> for ClaimRewards<'info>where
'info: 'info,
fn to_account_infos(&self) -> Vec<AccountInfo<'info>>
Sourceimpl<'info> ToAccountMetas for ClaimRewards<'info>
impl<'info> ToAccountMetas for ClaimRewards<'info>
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl<'info> Freeze for ClaimRewards<'info>
impl<'info> !RefUnwindSafe for ClaimRewards<'info>
impl<'info> !Send for ClaimRewards<'info>
impl<'info> !Sync for ClaimRewards<'info>
impl<'info> Unpin for ClaimRewards<'info>
impl<'info> UnsafeUnpin for ClaimRewards<'info>
impl<'info> !UnwindSafe for ClaimRewards<'info>